# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.

from datetime import date
from pathlib import Path

ROOT_DIR = Path(__file__).resolve(strict=True).parent.parent
PACKAGE_DIR = ROOT_DIR / "email_service"
DOCS_DIR = ROOT_DIR / "email_service"
version_file_path = PACKAGE_DIR / "version.py"

code_obj = compile(version_file_path.read_text(), version_file_path, "exec")
__version__ = dict()
exec(code_obj, __version__)
version = __version__["__version__"]

# -- Project information -----------------------------------------------------

project = "Email Service"
copyright = """2020, Aditya Raman"""
author = "Aditya Raman"

# The full version, including alpha/beta/rc tags
version = release = f"v{version}"
today = str(date.today())
language = "en"

# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx_rtd_theme",
    "sphinx.ext.autodoc",
    "sphinx.ext.napoleon",
    "sphinx.ext.viewcode",
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]

# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "sphinx_rtd_theme"  # alternate: "alabaster"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]
# These paths are either relative to html_static_path
# or fully qualified paths (eg. https://...)
# html_css_files = []
#
# html_style = ""

master_doc = "index"

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    "papersize": "a4paper",
    # The font size ('10pt', '11pt' or '12pt').
    #
    # 'pointsize': '10pt',
    # Additional stuff for the LaTeX preamble.
    #
    "preamble": "\\addto\\captionsenglish{\\renewcommand{\\contentsname}{Table of contents}}",
    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}
latex_show_urls = "footnote"

# If true, the current module name will be prepended to all description
# unit titles (such as .. function::).
add_module_names = False
add_function_parentheses = False
show_authors = True
